# FormService
[![GitHub top language](https://img.shields.io/github/languages/top/JeanPaulll/lib-form-service#readme.svg)]()
[![GitHub code size in bytes](https://img.shields.io/github/languages/code-size/JeanPaulll/lib-form-service.svg)]()
[![GitHub issues](https://img.shields.io/github/issues/JeanPaulll/lib-form-service.svg)]()
[![GitHub closed issues](https://img.shields.io/github/issues-closed/JeanPaulll/lib-form-service.svg)]()
[![GitHub contributors](https://img.shields.io/github/contributors/JeanPaulll/lib-form-service.svg)]()
[![GitHub](https://img.shields.io/github/license/mashape/apistatus.svg)](https://github.com/JeanPaulll/lib-form-service)
[![npm](https://img.shields.io/npm/v/handle-json-payload.svg)]()
[![Website](https://img.shields.io/website-up-down-green-red/http/shields.io.svg?label=agenciacriamais)](http://www.agenciacriamais.com.br)

The `FormService` is a utility library for creating Angular forms with ease. It provides a simple way to generate reactive forms and apply validations to form controls.

## Installation

You can install the FormService package using npm:

```bash
npm install form-service
```

## Usage

1. Import the necessary classes and interfaces from the `@angular/forms` module and the `form-service` package:

```
import { FormBuilder, FormGroup, FormControl, Validators, ValidatorFn, AsyncValidatorFn, AbstractControl } from '@angular/forms';
import { FormService, CampoConfig } from 'form-service';
```

2. Create an instance of `FormService` by injecting `FormBuilder`:

```
@Injectable({
providedIn: 'root'
})
export class YourFormService extends FormService {
constructor(private formBuilder: FormBuilder) {
super(formBuilder);
}

// Your custom form creation methods can go here
}
```

3. Define your form configuration using the `CampoConfig` interface:

```typescript
interface Phone {
  number: string;
  description: string;
  types: string[];
}

interface Person {
  name: string;
  age: number;
  phones: Phone[];
}

const phone: Phone = {
  number: '',
  description: '',
  types: []
};

const person: Person = {
  name: '',
  age: null,
  phones: [phone]
};
```

4. Use the `createForm` method from `FormService` to generate the form:

```typescript
const options: { [field: string]: CampoConfig } = {
  name: { value: '', validations: { required: true } },
  age: { value: null, validations: { required: true, min: 18 } },
  phones: { value: [], validations: { required: true } }
};

const personForm: FormGroup = this.createForm(person, options);
```

5. Use the generated form in your component template:

```html
<form [formGroup]="personForm">
    <label for="name">Name:</label>
    <input type="text" id="name" formControlName="name">
    <!-- More form controls for other fields... -->
</form>
```
6. Custom Validators
```typescript
const options: { [field: string]: CampoConfig } = {
    name: {
        value: '',
        customValidation: (control: AbstractControl) => {
            if (control.value && control.value.toLowerCase() === 'admin') {
                return {forbiddenName: true};
            }
            return null;
        }
    },
// Other fields...
};
```

## Help improve

Found a bug or a problem? [Open a new issue](https://github.com/JeanPaulll/lib-form-service/issues)  GitHub.

## Contributing to this project

[GitHub](https://github.com/JeanPaulll/lib-form-service)

## Author

[@JeanPaul](https://twitter.com/jeanpaullx) – jeanpaulwebb@gmail.com

[![GitHub contributors](https://img.shields.io/github/contributors/JeanPaulll/lib-form-service.svg)]()


License
This project is licensed under the MIT License - see the LICENSE file for details.




